/*
 * Copyright (c) 2019 - 2024 Stefan Strobel <stefan.strobel@shimatta.net>
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/.
 */

/**
 * @file    test_utils_saveCursorPos.c
 * @brief   unittest for shellmatta utils_saveCursorPos
 * @author  Stefan Strobel <stefan.strobel@shimatta.net>
 */

#include "test/framework/catch.hpp"
#include "src/shellmatta_utils.c"
#include <string.h>

static uint32_t write_callCnt = 0u;
static char write_data[10u];
static uint32_t write_length;

static shellmatta_retCode_t writeFct(const char* data, uint32_t length)
{
    write_callCnt ++;
    memcpy(write_data, data, length);
    write_length = length;
    return SHELLMATTA_OK;
}


TEST_CASE( "shellmatta_utils_saveCursorPos" ) {

    shellmatta_instance_t inst;
    char buffer[20];

    inst.buffer = buffer;
    inst.bufferSize = 20;
    inst.cursor = 10;
    inst.inputCount = 10;
    inst.echoEnabled = true;

    inst.write = writeFct;

    write_callCnt = 0u;
    memset(write_data, 0, sizeof(write_data));
    write_length = 0u;

    utils_saveCursorPos(&inst);

    CHECK( write_callCnt == 1u);
    CHECK( write_length == 3u);
    REQUIRE( strncmp("\x1b[s", write_data, 3u) == 0);
}
